@@ -57,7 +57,7 @@ var (
 var protocols = []Protocol{Compact, Binary}
 
 const internalMetrics = 5    // Additional metrics the reporter sends in a batch - use this, not a magic number.
-const cardinalityMetrics = 3 // Additional metrics emitted by the scope registry.
+const cardinalityMetrics = 4 // Additional metrics emitted by the scope registry.
 
 // TestReporter tests the reporter works as expected with both compact and binary protocols
 func TestReporter(t *testing.T) {
@@ -599,15 +599,18 @@ func TestReporterCommmonTagsInternal(t *testing.T) {
 			for k, v := range internalTags {
 				require.True(t, tagEquals(metric.Tags, k, v))
 			}
+
+			// The following tags should be redacted.
+			require.True(t, tagEquals(metric.Tags, "host", tally.DefaultTagRedactValue))
+			require.True(t, tagEquals(metric.Tags, "instance", tally.DefaultTagRedactValue))
 		} else {
 			require.Equal(t, "testCounter1", metric.Name)
 			require.False(t, tagIncluded(metric.Tags, "internal1"))
 			require.False(t, tagIncluded(metric.Tags, "internal2"))
 		}
+
 		// The following tags should not be present as part of the individual metrics
 		// as they are common tags.
-		require.False(t, tagIncluded(metric.Tags, "host"))
-		require.False(t, tagIncluded(metric.Tags, "instance"))
 		require.False(t, tagIncluded(metric.Tags, "service"))
 	}
 	require.Equal(t, internalMetrics, numInternalMetricsActual)
