@@ -1,4 +1,4 @@
-// Copyright (c) 2023 Uber Technologies, Inc.
+// Copyright (c) 2024 Uber Technologies, Inc.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -28,18 +28,9 @@ import (
 	"go.uber.org/atomic"
 )
 
-// InternalMetricOption is used to configure internal metrics.
-type InternalMetricOption int
-
 const (
-	// Unset is the "no-op" config, which turns off internal metrics.
-	Unset InternalMetricOption = iota
-	// SendInternalMetrics turns on internal metrics submission.
-	SendInternalMetrics
-	// OmitInternalMetrics turns off internal metrics submission.
-	OmitInternalMetrics
-
-	_defaultInitialSliceSize = 16
+	_defaultInitialSliceSize  = 16
+	_defaultReportingInterval = 2 * time.Second
 )
 
 var (
@@ -101,19 +92,23 @@ type scope struct {
 	done        chan struct{}
 	wg          sync.WaitGroup
 	root        bool
+	testScope   bool
 }
 
 // ScopeOptions is a set of options to construct a scope.
 type ScopeOptions struct {
-	Tags               map[string]string
-	Prefix             string
-	Reporter           StatsReporter
-	CachedReporter     CachedStatsReporter
-	Separator          string
-	DefaultBuckets     Buckets
-	SanitizeOptions    *SanitizeOptions
+	Tags                   map[string]string
+	Prefix                 string
+	Reporter               StatsReporter
+	CachedReporter         CachedStatsReporter
+	Separator              string
+	DefaultBuckets         Buckets
+	SanitizeOptions        *SanitizeOptions
+	OmitCardinalityMetrics bool
+	CardinalityMetricsTags map[string]string
+
+	testScope          bool
 	registryShardCount uint
-	MetricsOption      InternalMetricOption
 }
 
 // NewRootScope creates a new root Scope with a set of options and
@@ -124,6 +119,12 @@ func NewRootScope(opts ScopeOptions, interval time.Duration) (Scope, io.Closer)
 	return s, s
 }
 
+// NewRootScopeWithDefaultInterval invokes NewRootScope with the default
+// reporting interval of 2s.
+func NewRootScopeWithDefaultInterval(opts ScopeOptions) (Scope, io.Closer) {
+	return NewRootScope(opts, _defaultReportingInterval)
+}
+
 // NewTestScope creates a new Scope without a stats reporter with the
 // given prefix and adds the ability to take snapshots of metrics emitted
 // to it.
@@ -131,7 +132,11 @@ func NewTestScope(
 	prefix string,
 	tags map[string]string,
 ) TestScope {
-	return newRootScope(ScopeOptions{Prefix: prefix, Tags: tags}, 0)
+	return newRootScope(ScopeOptions{
+		Prefix:    prefix,
+		Tags:      tags,
+		testScope: true,
+	}, 0)
 }
 
 func newRootScope(opts ScopeOptions, interval time.Duration) *scope {
@@ -176,6 +181,7 @@ func newRootScope(opts ScopeOptions, interval time.Duration) *scope {
 		separator:       sanitizer.Name(opts.Separator),
 		timers:          make(map[string]*timer),
 		root:            true,
+		testScope:       opts.testScope,
 	}
 
 	// NB(r): Take a copy of the tags on creation
@@ -183,7 +189,7 @@ func newRootScope(opts ScopeOptions, interval time.Duration) *scope {
 	s.tags = s.copyAndSanitizeMap(opts.Tags)
 
 	// Register the root scope
-	s.registry = newScopeRegistryWithShardCount(s, opts.registryShardCount, opts.MetricsOption)
+	s.registry = newScopeRegistryWithShardCount(s, opts.registryShardCount, opts.OmitCardinalityMetrics, opts.CardinalityMetricsTags)
 
 	if interval > 0 {
 		s.wg.Add(1)
